#!/bin/bash

FORCE=""

error() {
	printf "%s\n" "$@" >&2
	exit 1
}

usage() {
	printf "%s [--force]\n" "$0"
}

package() {
	local tag deb_version inexact=""

	git diff-index --quiet HEAD \
		|| error "git directory is not clean, commit or checkout first"

	if ! tag=$(git describe --tags --exact-match); then
		[[ -n "$FORCE" ]] || error "Use --force to allow building a non-tag commit"
		inexact=1
		tag=$(git describe --tags | sed -e 's/-/+/g')

	fi

	deb_version=$(dpkg-parsechangelog --show-field Version) \
		|| error "Could not parse debian/changelog"
	if [[ "${deb_version%-*}" != "$tag" ]]; then
		[[ -n "$FORCE" ]] \
			|| error "Debian version $deb_version does not match last tag $tag"
		echo "Debian version $deb_version does not match current tag $tag, updating changelog..."
		dch ${inexact:+-b} -v "$tag-1" "Auto version" \
			|| error "Could not update changelog"
	fi

	git archive HEAD --prefix=linux-firmware-atmark_"$tag/" \
			-o ../linux-firmware-atmark_"$tag".orig.tar.gz \
		|| error "Could not build archive"

	debuild -us -uc \
		|| error "Could not build package"
}

main() {
	local arg
	for arg; do
		case "$arg" in
		--force)
			FORCE=1
			;;
		--help|-h)
			usage
			exit 0
			;;
		*)
			usage
			error "Unknown option $arg"
			;;
		esac
	done
	package
}

main "$@"
